package Crypt::Mode;

use strict;
use warnings;
our $VERSION = '0.088_003';

### not used

1;

=pod

=head1 NAME

Crypt::Mode - [internal only]

=head1 SYNOPSIS

Do not use this module directly.

Use a concrete block-mode module such as L<Crypt::Mode::CBC> or
L<Crypt::Mode::CTR>.

=head1 DESCRIPTION

Internal namespace placeholder for block-cipher mode modules.

Do not use this module directly. Use a concrete mode such as
L<Crypt::Mode::CBC>, L<Crypt::Mode::CFB>, L<Crypt::Mode::CTR>,
L<Crypt::Mode::ECB>, or L<Crypt::Mode::OFB>.

=cut
